@@ -2,7 +2,7 @@ from __future__ import absolute_import
 
 import math
 from enum import Enum
-from typing import TYPE_CHECKING, Dict, List, Optional, Tuple, Union, overload, Text
+from typing import TYPE_CHECKING, Dict, List, Optional, Text, Tuple, Union, overload
 
 import attr
 from PIL.Image import Image
@@ -353,7 +353,7 @@ class AccessibilityRegion(Rectangle):
     width = attr.ib(metadata={JsonInclude.THIS: True})  # type: int
     height = attr.ib(metadata={JsonInclude.THIS: True})  # type: int
     type = attr.ib(
-        type=AccessibilityRegionType, metadata={JsonInclude.THIS: True},
+        type=AccessibilityRegionType, metadata={JsonInclude.THIS: True}
     )  # type: AccessibilityRegionType
 
     def __init__(
