@@ -6,19 +6,21 @@ import attr
 
 from applitools.common import logger
 from applitools.common.geometry import RectangleSize, Region
-from applitools.common.selenium.misc import BrowserType
 from applitools.common.utils import general_utils, json_utils
 from applitools.common.utils.json_utils import JsonInclude
+
 from .render_browser_info import (
-    IosDeviceInfo,
-    IRenderBrowserInfo,
     ChromeEmulationInfo,
     EmulationBaseInfo,
+    IosDeviceInfo,
+    IRenderBrowserInfo,
 )
 
 if typing.TYPE_CHECKING:
-    from typing import List, Text, Dict, Optional, Callable, Union, Any
+    from typing import Any, Callable, Dict, List, Optional, Text, Union
+
     from requests import Response
+
     from applitools.common.utils.custom_types import Num
     from applitools.selenium.visual_grid.vg_task import VGTask
 
@@ -168,11 +170,16 @@ class RGridDom(object):
 
 @attr.s(slots=True)
 class VGResource(object):
+    MAX_RESOURCE_SIZE = 15 * 1024 * 1024  # type: int
+
     url = attr.ib()  # type: Text
     content_type = attr.ib(metadata={JsonInclude.THIS: True})  # type: Text
     content = attr.ib(repr=False)  # type: bytes
     msg = attr.ib(default=None)  # type: Optional[Text]
-    hash = attr.ib(init=False, metadata={JsonInclude.THIS: True})  # type: Text
+    error_status_code = attr.ib(
+        default=None, hash=False, metadata={JsonInclude.NON_NONE: True}
+    )  # type: Optional[Text]
+    hash = attr.ib(init=False, metadata={JsonInclude.NON_NONE: True})  # type: Text
     hash_format = attr.ib(
         init=False, default="sha256", metadata={JsonInclude.THIS: True}
     )  # type: Text
@@ -182,6 +189,12 @@ class VGResource(object):
         return self.hash
 
     def __attrs_post_init__(self):
+        if len(self.content) > self.MAX_RESOURCE_SIZE:
+            logger.debug(
+                "The content of {} is bigger then supported max size. "
+                "Trimming to {} bytes".format(self.url, self.MAX_RESOURCE_SIZE)
+            )
+            self.content = self.content[: self.MAX_RESOURCE_SIZE]
         self.hash = general_utils.get_sha256_hash(self.content)
         if callable(self._handle_func):
             try:
@@ -192,41 +205,43 @@ class VGResource(object):
                     " of VGResource({})".format(self.url),
                 )
 
-    @classmethod
-    def EMPTY(cls, url):
-        return cls(url, "application/empty-response", b"")
-
     @classmethod
     def from_blob(cls, blob, on_created=None):
         # type: (Dict, Callable) -> VGResource
         content = base64.b64decode(blob.get("value", ""))
         content_type = blob.get("type")
         url = blob.get("url")
+        error_status = blob.get("errorStatusCode")
+
         return cls(
             url,
             content_type,
             content,
-            handle_func=lambda: on_created(content_type, content, url),
+            error_status_code=error_status,
+            handle_func=(
+                lambda: on_created(content_type, content, url)
+                if error_status is None
+                else None
+            ),
         )
 
     @classmethod
     def from_response(cls, url, response, on_created=None):
         # type: (Text, Response, Callable) -> VGResource
-        if not response.ok:
-            logger.debug(
-                "We've got response code {} {} for URL {}".format(
-                    response.status_code, response.reason, url
-                )
-            )
-            return VGResource.EMPTY(url)
-
-        content_type = response.headers.get("Content-Type")
         content = response.content
+        content_type = response.headers.get("Content-Type")
+        error_status = None if response.ok else str(response.status_code)
+
         return cls(
             url,
             content_type,
             content,
-            handle_func=lambda: on_created(content_type, content, url),
+            error_status_code=error_status,
+            handle_func=(
+                lambda: on_created(content_type, content, url)
+                if error_status is None
+                else None
+            ),
         )
 
 
@@ -329,5 +344,8 @@ class RenderStatusResults(object):
         default=None, metadata={JsonInclude.THIS: True}
     )  # type: Optional[Text]
     visual_viewport = attr.ib(
-        default=None, type=RectangleSize, metadata={JsonInclude.THIS: True}
+        default=None,
+        type=RectangleSize,
+        converter=attr.converters.optional(RectangleSize.from_),
+        metadata={JsonInclude.THIS: True},
     )  # type: Optional[RectangleSize]
